@@ -3,7 +3,7 @@ BEGIN {
   $Bio::GFF3::LowLevel::Parser::AUTHORITY = 'cpan:RBUELS';
 }
 {
-  $Bio::GFF3::LowLevel::Parser::VERSION = '1.8';
+  $Bio::GFF3::LowLevel::Parser::VERSION = '1.9';
 }
 # ABSTRACT: a fast, low-level gff3 parser
 
@@ -129,7 +129,7 @@ sub _buffer_items {
         }
         else { # it's a parse error
             chomp $line;
-            croak "$self->{filethings}[0]:$.: parse error.  Cannot parse '$line'.";
+            $self->_parse_error("parse error.  Cannot parse '$line'.");
         }
 
         # buffer old features if we are starting to approach our mem limit
@@ -144,6 +144,11 @@ sub _buffer_items {
     $self->_buffer_all_under_construction_features;
 }
 
+sub _parse_error {
+    my ( $self, $error ) = @_;
+    croak "$self->{filethings}[0]:$.: $error";
+}
+
 ## take all under-construction features and put them in the
 ## item_buffer to be output
 sub _buffer_all_under_construction_features {
@@ -274,6 +279,9 @@ sub _buffer_feature {
     for my $id ( @$ids ) {
         if( my $existing = $self->{under_construction_by_id}{$id} ) {
             # another location of the same feature
+            unless( $existing->[-1]->{type} eq $feature_line->{type} ) {
+                $self->_parse_error("type ".$feature_line->{type}." is not the same as previous type ".$existing->[-1]->{type}." for ID '".$id."'");
+            }
             push @$existing, $feature_line;
             $feature = $existing;
         }
